# Contributors

* agateriver ([@agateriver](https://crowdin.com/profile/agateriver))
* MountLation ([@MountLation](https://crowdin.com/profile/MountLation))
* Yuze Ma ([@bobmayuze](https://crowdin.com/profile/bobmayuze))
* Chuhan Feng ([@simonrouse9461](https://crowdin.com/profile/simonrouse9461))
* Shuihan Yi ([@yshemily](https://crowdin.com/profile/yshemily))
* Allan Chain ([@AllanChain](https://crowdin.com/profile/AllanChain))
* 顽皮绅士 ([@Hadboon](https://crowdin.com/profile/Hadboon))
* Gonzalo Peña-Castellanos ([@goanpeca](https://crowdin.com/profile/goanpeca))
